@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ManagedReportInfo.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: ManagedReportInfo.h 1336 2006-09-26 18:09:50Z cs $
  */
 
 #ifndef _ManagedReportInfo_h_
@@ -17,7 +17,7 @@
 
 class KListViewItem;
 class ReportManager;
-class TjReportBase;
+class TjUIReportBase;
 class Report;
 
 class ManagedReportInfo
@@ -33,8 +33,8 @@ public:
     void setBrowserEntry(KListViewItem* lvi) { browserEntry = lvi; }
     KListViewItem* getBrowserEntry() const { return browserEntry; }
 
-    void setReport(TjReportBase* r) { report = r; }
-    TjReportBase* getReport() const { return report; }
+    void setReport(TjUIReportBase* r) { report = r; }
+    TjUIReportBase* getReport() const { return report; }
 
     void setLoadingProject(bool lp);
 
@@ -47,7 +47,7 @@ private:
     Report* const projectReport;
 
     KListViewItem* browserEntry;
-    TjReportBase* report;
+    TjUIReportBase* report;
 
     bool loadingProject;
 } ;
