@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportManager.cpp 1311 2006-07-21 13:11:15Z cs $
+ * $Id: ReportManager.cpp 1343 2006-10-04 07:32:28Z cs $
  */
 
 #include "ReportManager.h"
@@ -39,13 +39,18 @@
 #include "ExportReport.h"
 
 #include "ManagedReportInfo.h"
-#include "TjReportBase.h"
+#include "TjUIReportBase.h"
 #include "TjSummaryReport.h"
 #include "TjHTMLReport.h"
 #include "TjTaskReport.h"
 #include "TjResourceReport.h"
 #include "MainWidget.h"
 
+// Older versions of KDE do not have this macro
+#ifndef KDE_IS_VERSION
+#define KDE_IS_VERSION(a,b,c) 0
+#endif
+
 ReportManager::ReportManager(KMainWindow* m, QWidgetStack* v,
                              KListView* b, KListViewSearchLine* s) :
     mainWindow(m), reportStack(v), browser(b), searchLine(s)
@@ -360,7 +365,7 @@ ReportManager::showReport(QListViewItem* lvi, bool& showReportTab)
                 mr = *mri;
     }
 
-    TjReportBase* tjr = mr->getReport();
+    TjUIReportBase* tjr = mr->getReport();
     if (tjr == 0)
     {
         if (mr->getProjectReport() == 0)
