@@ -7,13 +7,13 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjHTMLReport.h 1275 2006-03-05 19:16:55Z cs $
+ * $Id: TjHTMLReport.h 1336 2006-09-26 18:09:50Z cs $
  */
 
 #ifndef _TjHTMLReport_h_
 #define _TjHTMLReport_h_
 
-#include "TjReportBase.h"
+#include "TjUIReportBase.h"
 
 #include <kparts/browserrun.h>
 
@@ -22,7 +22,7 @@ class KHTMLPart;
 class Project;
 class Report;
 
-class TjHTMLReport : public TjReportBase
+class TjHTMLReport : public TjUIReportBase
 {
     Q_OBJECT
 
