@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjReport.cpp 1315 2006-08-11 21:05:41Z cs $
+ * $Id: TjReport.cpp 1374 2007-01-28 16:49:27Z cs $
  */
 
 #include "TjReport.h"
@@ -63,7 +63,7 @@
 
 TjReport::TjReport(QWidget* p, ReportManager* m, Report* const rDef,
                    const QString& n)
-    : TjReportBase(p, m, rDef, n)
+    : TjUIReportBase(p, m, rDef, n)
 {
     loadingProject = FALSE;
     autoFit = true;
@@ -150,7 +150,7 @@ TjReport::print()
     printer->setResolution(300);
     printer->setCreator(QString("TaskJuggler %1 - visit %2")
                         .arg(VERSION).arg(TJURL));
-    if (!printer->setup(this, i18n("Print %1").arg(reportDef->getFileName())))
+    if (!printer->setup(this, i18n("Print %1").arg(report->getFileName())))
         goto done;
 
     /* This is a hack to workaround the problem that the KPrinter settings
@@ -287,17 +287,36 @@ TjReport::generateTaskListLine(const QtReportElement* reportElement,
 
         if ((*ci)->getName() == "completed")
         {
-            if (t->getCompletionDegree(scenario) ==
-                t->getCalcedCompletionDegree(scenario))
+            double calcedCompletionDegree =
+                t->getCalcedCompletionDegree(scenario);
+            double providedCompletionDegree =
+                t->getCompletionDegree(scenario);
+
+            if (calcedCompletionDegree < 0)
             {
-                cellText = QString("%1%")
-                    .arg((int) t->getCompletionDegree(scenario));
+                if (calcedCompletionDegree == providedCompletionDegree)
+                {
+                    cellText = i18n("in progress");
+                }
+                else
+                {
+                    cellText = QString(i18n("%1% (in progress)"))
+                        .arg((int) providedCompletionDegree);
+                }
             }
             else
             {
-                cellText = QString("%1% (%2%)")
-                    .arg((int) t->getCompletionDegree(scenario))
-                    .arg((int) t->getCalcedCompletionDegree(scenario));
+                if (calcedCompletionDegree == providedCompletionDegree)
+                {
+                    cellText = QString("%1%")
+                        .arg((int) providedCompletionDegree);
+                }
+                else
+                {
+                    cellText = QString("%1% (%2%)")
+                            .arg((int) providedCompletionDegree)
+                            .arg((int) calcedCompletionDegree);
+                }
             }
         }
         else if ((*ci)->getName() == "cost")
@@ -537,7 +556,7 @@ TjReport::generateResourceListLine(const QtReportElement* reportElement,
                 cellText = i18n("no Limits");
             else
             {
-                int sg = reportDef->getProject()->getScheduleGranularity();
+                int sg = report->getProject()->getScheduleGranularity();
                 if (limits->getDailyMax() > 0)
                     cellText = i18n("D: %1h").arg(limits->getDailyMax() *
                                                sg / (60 * 60));
@@ -673,7 +692,7 @@ TjReport::prepareChart()
         QStringList tokens = QStringList::split(":", (*lvit).first);
         CoreAttributes* ca1 = 0;
         CoreAttributes* ca2 = 0;
-        const Project* project = reportDef->getProject();
+        const Project* project = report->getProject();
         if (tokens[0] == "t")
         {
             if (tokens[2].isEmpty())
@@ -774,6 +793,8 @@ TjReport::generateListHeader(const QString& firstHeader, QtReportElement* tab)
     listView->setSortOrder(Qt::Ascending);
     listView->setSortColumn(1);
 
+    lvCol2tci.clear();
+
     showGantt = false;
     int col = 2;
     for (QPtrListIterator<TableColumnInfo>
@@ -796,6 +817,9 @@ TjReport::generateListHeader(const QString& firstHeader, QtReportElement* tab)
             continue;
         }
 
+        /* Store a reference to the column info in the lvCol2tci map. */
+        lvCol2tci.insert(lvCol2tci.end(), ci);
+
         const TableColumnFormat* tcf =
             tab->getColumnFormat((*ci)->getName());
         QString title = tcf->getTitle();
@@ -837,8 +861,7 @@ TjReport::listClicked(QListViewItem* lvi, const QPoint&, int column)
         return;
 
     CoreAttributes* ca = lvi2caDict[QString().sprintf("%p", lvi)];
-    const TableColumnInfo* tci =
-        this->getReportElement()->columnsAt(column - 2);
+    const TableColumnInfo* tci = lvCol2tci[column - 2];
 
     if (ca->getType() == CA_Task &&
         tci->getName() == "note" &&
@@ -974,16 +997,9 @@ TjReport::showTaskDetails(const Task* task)
     richTextDisplay->textDisplay->setTextFormat(Qt::RichText);
 
     QString text;
-    if (task->isMilestone())
-    {
-        text += i18n("<b>Date:</b> %1<br/>")
-            .arg(time2tjp(task->getStart(scenario)));
-    }
-    else
-        text += i18n("<b>Start:</b> %1<br/>"
-                     "<b>End:</b> %2<br/>")
-            .arg(time2tjp(task->getStart(scenario)))
-            .arg(time2tjp(task->getEnd(scenario) + 1));
+    text = i18n("<b>Task:</b> %1 (%2)<br/>")
+        .arg(task->getName())
+        .arg(task->getId());
 
     if (!task->getNote().isEmpty())
     {
@@ -992,36 +1008,91 @@ TjReport::showTaskDetails(const Task* task)
         text += i18n("<b>Note:</b> %1<br/>").arg(task->getNote());
     }
 
+    if (task->isMilestone())
+    {
+        if (!text.isEmpty())
+            text += "<hr/>";
+        text += i18n("<b>Date:</b> %1<br/>")
+            .arg(time2tjp(task->getStart(scenario)));
+    }
+    else
+    {
+        if (!text.isEmpty())
+            text += "<hr/>";
+        text += i18n("<b>Start:</b> %1<br/>"
+                     "<b>End:</b> %2<br/>"
+                     "<b>Status:</b> %3<br/>")
+            .arg(time2tjp(task->getStart(scenario)))
+            .arg(time2tjp(task->getEnd(scenario) + 1))
+            .arg(task->getStatusText(scenario));
+
+        if (task->getEffort(scenario) > 0.0)
+        {
+            const ReportElement* reportElement = getReportElement();
+            double completion = task->getCompletionDegree(scenario) / 100.0;
+            text += i18n("<hr/><b>Effort:</b> %1<br/>");
+            if (completion < 0.0)
+            {
+                text += i18n("<b>Completion degree:</b> in progress<br/>");
+            }
+            else
+            {
+                text += i18n("<b>Completion degree:</b> %2%<br/>"
+                             "<b>Done effort:</b> %3<br/>"
+                             "<b>Remaining effort:</b> %4<br/>")
+                    .arg(reportElement->scaledLoad
+                         (task->getEffort(scenario), report->getNumberFormat(),
+                          true, false))
+                    .arg(task->getCompletionDegree(scenario))
+                    .arg(reportElement->scaledLoad
+                         (task->getEffort(scenario) * completion,
+                          report->getNumberFormat(), true, false))
+                    .arg(reportElement->scaledLoad
+                         (task->getEffort(scenario) * (1.0 - completion),
+                          report->getNumberFormat(), true, false));
+            }
+        }
+
+        if (!task->getStatusNote(scenario).isEmpty())
+            text += i18n("<b>Note:</b> %1<br/>")
+                .arg(task->getStatusNote(scenario));
+    }
+
     QString predecessors;
     for (TaskListIterator tli(task->getPreviousIterator()); *tli; ++tli)
-    {
-        if (!predecessors.isEmpty())
-            predecessors += ", ";
-        predecessors += (*tli)->getName() + "(" + (*tli)->getId() + ")";
-    }
+        predecessors += "<li>" + (*tli)->getName() + " (" + (*tli)->getId() +
+            ")</li>";
 
     QString successors;
     for (TaskListIterator tli(task->getFollowersIterator()); *tli; ++tli)
-    {
-        if (!successors.isEmpty())
-            successors += ", ";
-        successors += (*tli)->getName() + " (" + (*tli)->getId() + ")";
-    }
+        successors += "<li>" + (*tli)->getName() + " (" + (*tli)->getId() +
+            ")<li/>";
 
     if (!predecessors.isEmpty() || !successors.isEmpty())
     {
-        if (!text.isEmpty())
-            text += "<hr/>";
+        text += "<hr/>";
         if (!predecessors.isEmpty())
-            text += i18n("<b>Predecessors:</b> %1<br/>").arg(predecessors);
+            text += i18n("<b>Predecessors:</b><ul>%1</ul><br/>")
+                .arg(predecessors);
         if (!successors.isEmpty())
-            text += i18n("<b>Successors:</b> %1<br/>").arg(successors);
+            text += i18n("<b>Successors:</b><ul>%1</ul><br/>").arg(successors);
     }
 
+    ResourceListIterator rli = task->getBookedResourcesIterator(scenario);
+    if (*rli)
+    {
+        text += "<hr/><b>Allocated resources:</b><ul>";
+        for (; *rli; ++rli)
+            text += "<li>" + (*rli)->getName() + " (" + (*rli)->getId() +
+                ")</li>";
+        text += "</ul>";
+    }
+
+    text += generateRTCustomAttributes(task);
+
     if (task->hasJournal())
     {
-        if (!text.isEmpty())
-            text += "<hr/>";
+        text += "<hr/>";
         text += generateJournal(task->getJournalIterator());
     }
 
@@ -1030,7 +1101,7 @@ TjReport::showTaskDetails(const Task* task)
 }
 
 void
-TjReport::showResourceDetails(const Resource* resource)
+TjReport::showResourceDetails(Resource* resource)
 {
     RichTextDisplay* richTextDisplay = new RichTextDisplay(topLevelWidget());
     richTextDisplay->setCaption
@@ -1039,6 +1110,20 @@ TjReport::showResourceDetails(const Resource* resource)
     richTextDisplay->textDisplay->setTextFormat(Qt::RichText);
 
     QString text;
+    Interval iv = Interval(report->getStart(),
+                           report->getEnd());
+    double load = resource->getLoad(scenario, iv);
+    double freeLoad = resource->getAvailableWorkLoad(scenario, iv);
+
+    text = i18n("<b>Resource:</b> %1 (%2)<br/>")
+        .arg(resource->getName())
+        .arg(resource->getId());
+
+    text += i18n("<hr><b>Effort:</b> %1 <b>Free Load:</b> %2 "
+                "<b>Utilization:</b> %3%")
+        .arg(scaledLoad(load, numberFormat, true))
+        .arg(scaledLoad(freeLoad, numberFormat, true))
+        .arg((int) (load / (load + freeLoad) * 100.0));
 
     if (resource->hasJournal())
     {
@@ -1047,10 +1132,56 @@ TjReport::showResourceDetails(const Resource* resource)
         text += generateJournal(resource->getJournalIterator());
     }
 
+    text += generateRTCustomAttributes(resource);
+
+    if (resource->hasJournal())
+    {
+        text += "<hr/>";
+        text += generateJournal(resource->getJournalIterator());
+    }
+
     richTextDisplay->textDisplay->setText(text);
     richTextDisplay->show();
 }
 
+QString
+TjReport::generateRTCustomAttributes(const CoreAttributes* ca) const
+{
+    QDict<CustomAttribute> caDict = ca->getCustomAttributeDict();
+
+    QString text = "<hr/>";
+    if (caDict.isEmpty())
+        return text;
+
+    for (QDictIterator<CustomAttribute> cadi(caDict); cadi.current(); ++cadi)
+    {
+        text += "<b>" + cadi.currentKey() + ":</b> ";
+        CustomAttribute* custAttr = cadi.current();
+        switch (cadi.current()->getType())
+        {
+            case CAT_Reference:
+            {
+                QString label = dynamic_cast<const
+                    ReferenceAttribute*>(custAttr)->getLabel();
+                QString url = dynamic_cast<const
+                    ReferenceAttribute*>(custAttr)->getURL();
+                text += "<a href=\"" + url + "\">" +
+                    (label.isEmpty() ? url : label) + "</a>";
+                break;
+            }
+            case CAT_Text:
+                text += dynamic_cast<const TextAttribute*>(custAttr)->
+                    getText();
+                break;
+            case CAT_Undefined:
+                break;
+        }
+        text += "<br/>";
+    }
+
+    return text;
+}
+
 void
 TjReport::syncVSlidersGantt2List(int x, int y)
 {
@@ -1239,7 +1370,7 @@ TjReport::generateJournal(JournalIterator jit) const
 
     for ( ; *jit; ++jit)
         text += "<b><i>" + time2user((*jit)->getDate(),
-                                     reportDef->getTimeFormat()) +
+                                     report->getTimeFormat()) +
             "</i></b><br/>" + (*jit)->getText() + "<br/>";
 
     return text;
