@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjResourceReport.cpp 1327 2006-09-03 08:28:26Z cs $
+ * $Id: TjResourceReport.cpp 1368 2007-01-12 14:18:34Z cs $
  */
 
 #include "TjResourceReport.h"
@@ -45,7 +45,7 @@ TjResourceReport::~TjResourceReport()
 TjPrintReport*
 TjResourceReport::newPrintReport(KPrinter* pr)
 {
-    return new TjPrintResourceReport(reportDef, pr);
+    return new TjPrintResourceReport(report, pr);
 }
 
 const QtReportElement*
@@ -66,16 +66,16 @@ TjResourceReport::generateList()
         listView->removeColumn(0);
     maxDepth = 0;
 
-    if (!reportDef)
+    if (!report)
         return FALSE;
 
     // We need those values frequently. So let's store them in a more
     // accessible place.
     reportElement =
-        (dynamic_cast<QtResourceReport*>(reportDef))->getTable();
+        (dynamic_cast<QtResourceReport*>(report))->getTable();
     scenario = reportElement->getScenario(0);
-    resourceList = reportDef->getProject()->getResourceList();
-    taskList = reportDef->getProject()->getTaskList();
+    resourceList = report->getProject()->getResourceList();
+    taskList = report->getProject()->getTaskList();
 
     if (!reportElement->filterResourceList
         (resourceList, 0, reportElement->getHideResource(), 0))
@@ -108,6 +108,8 @@ TjResourceReport::generateList()
         else
             newLvi = new KListViewItem(listView, (*rli)->getName());
 
+        newLvi->setText(1, QString().sprintf("%07d", i++));
+
         // Store the new LVI into the dictionary and check if we have reached
         // a new tree level maximum.
         ca2lviDict[QString("r:") + (*rli)->getId()] = newLvi;
@@ -125,7 +127,7 @@ TjResourceReport::generateList()
                               loadIcon("tj_resource_group", KIcon::Small));
             if (reportElement->getRollUpResource())
             {
-                if (!reportDef->isRolledUp(*rli,
+                if (!report->isRolledUp(*rli,
                                            reportElement->getRollUpResource()))
                     newLvi->setOpen(TRUE);
                 // Check if during the evaluation of the expression an error
@@ -175,6 +177,8 @@ TjResourceReport::generateList()
                     // Insert the task as child of the resource.
                     lvi = new KListViewItem(newLvi, (*tli)->getName());
                 }
+                lvi->setText(1, QString().sprintf("%07d", i++));
+
                 // The the proper icon for the task.
                 lvi->setPixmap(0, KGlobal::iconLoader()->
                                loadIcon(((*tli)->isContainer() ?
@@ -192,7 +196,6 @@ TjResourceReport::generateList()
                     maxDepth = treeLevel(lvi);
             }
         }
-        newLvi->setText(1, QString().sprintf("%05d", i++));
     }
 
     // Now we know the maximum tree depth and can fill in the rest of the
@@ -240,9 +243,9 @@ TjResourceReport::generateStatusBarText(const QPoint& pos,
             .arg(r->getId())
             .arg(ivName)
             .arg(reportElement->scaledLoad
-                 (load, reportDef->getNumberFormat(), true, false))
+                 (load, report->getNumberFormat(), true, false))
             .arg(reportElement->scaledLoad
-                 (allocatedTimeLoad, reportDef->getNumberFormat(), true, false))
+                 (allocatedTimeLoad, report->getNumberFormat(), true, false))
             .arg(t->getName())
             .arg(t->getId());
     }
@@ -262,14 +265,14 @@ TjResourceReport::generateStatusBarText(const QPoint& pos,
             .arg(r->getId())
             .arg(ivName)
             .arg(reportElement->scaledLoad
-                 (load, reportDef->getNumberFormat(), true, false))
+                 (load, report->getNumberFormat(), true, false))
             .arg(totalLoad > 0.0 ? (int) ((load / totalLoad) * 100.0): 100)
             .arg(reportElement->scaledLoad
-                 (allocatedTimeLoad, reportDef->getNumberFormat(), true, false))
+                 (allocatedTimeLoad, report->getNumberFormat(), true, false))
             .arg(totalTimeLoad > 0.0 ?
                  (int) ((allocatedTimeLoad / totalTimeLoad) * 100.0) : 100)
             .arg(reportElement->scaledLoad
-                 (freeLoad, reportDef->getNumberFormat(), true, false));
+                 (freeLoad, report->getNumberFormat(), true, false));
     }
 
     return text;
