@@ -7,19 +7,19 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TjSummaryReport.h 1275 2006-03-05 19:16:55Z cs $
+ * $Id: TjSummaryReport.h 1336 2006-09-26 18:09:50Z cs $
  */
 
 #ifndef _TjSummaryReport_h_
 #define _TjSummaryReport_h_
 
-#include "TjReportBase.h"
+#include "TjUIReportBase.h"
 
 class Project;
 class Report;
 class QTextBrowser;
 
-class TjSummaryReport : public TjReportBase
+class TjSummaryReport : public TjUIReportBase
 {
     Q_OBJECT
 
