@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: taskjugglerview.cpp 1328 2006-09-03 10:24:28Z cs $
+ * $Id: taskjugglerview.cpp 1351 2006-10-31 20:34:24Z cs $
  */
 
 #include "taskjugglerview.h"
@@ -518,11 +518,15 @@ TaskJugglerView::close()
 void
 TaskJugglerView::closeProject()
 {
+    // Remove the editor component
+    hideEditor();
+
     // Give the user the option to save all modified files.
     fileManager->saveAllFiles(true);
 
     // Clear all project specific data structures.
     fileManager->clear();
+
     reportManager->clear();
     mw->taskListView->clear();
     mw->resourceListView->clear();
@@ -682,19 +686,21 @@ TaskJugglerView::loadProject(const KURL& url)
 
     emit announceRecentURL(url);
 
-    bool errors = FALSE;
+    int errors = 0;
+    int warnings = 0;
     mw->messageListView->clear();
     messageCounter = 0;
     if (!pf->parse())
-        errors = TRUE;
+        errors++;
     delete pf;
     changeStatusBar(i18n("Checking project..."));
     bool fatalError = false;
-    if ((!errors && !project->pass2(FALSE, fatalError)) || fatalError)
-        errors = TRUE;
+    if (errors == 0)
+        project->pass2(false, fatalError, errors, warnings);
+
     changeStatusBar(i18n("Scheduling..."));
-    if (!errors && !project->scheduleAllScenarios())
-        errors = TRUE;
+    if (errors == 0)
+        project->scheduleAllScenarios(errors, warnings);
 
     // Load tasks into Task List View
     updateTaskList();
@@ -715,16 +721,11 @@ TaskJugglerView::loadProject(const KURL& url)
     (dynamic_cast<TaskJuggler*>(parent()))->enableActions(true);
     setLoadingProject(FALSE);
 
-    // We handle warnings like errors, so in case there any messages, we open
-    // the message window.
-    if (messageCounter)
-        errors = TRUE;
-
     // Show message list when errors have occured
     QValueList<int> vl;
     int h = mw->editorSplitter->height();
     KMainWindow* mainWindow = dynamic_cast<KMainWindow*>(parent());
-    if (errors)
+    if (errors > 0 || warnings > 0)
     {
         // The messages should be visible, so we check whether we already have
         // a setting for the splitter that is large enough. Otherwise we make
