@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: HTMLWeeklyCalendarElement.h 1313 2006-07-27 10:50:04Z cs $
+ * $Id: HTMLWeeklyCalendarElement.h 1373 2007-01-25 15:13:13Z cs $
  */
 
 #ifndef _HTMLWeeklyCalendarElement_h_
@@ -24,24 +24,27 @@ public:
     ~HTMLWeeklyCalendarElement();
 
     void setDaysToShow(QBitArray& days);
+    void setTaskReport(bool tRep) { taskReport = tRep; }
 
     bool generate();
 
 private:
     void generateTableHeader(bool weekStartsMonday);
     void generateWeekHeader(bool weekStartsMonday, time_t week);
-    void generateTaksPerDay(time_t& week, TaskList& filteredTaskList,
+    bool generateTaksPerDay(time_t& week, TaskList& filteredTaskList,
+                            ResourceList& filteredResourceList,
                             bool weekStartsMonday);
-    void generateResourcesPerDay(time_t& week,
+    bool generateResourcesPerDay(time_t& week,
                                  ResourceList& filteredResourceList,
+                                 TaskList& filteredTaskList,
                                  bool weekStartsMonday);
 
     bool showThisDay(int dayIndex, bool weekStartsMonday);
-
     HTMLWeeklyCalendarElement() { }
 
     QBitArray daysToShow;
     unsigned int numberOfDays;
+    bool taskReport;
 } ;
 
 #endif
