@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.cpp 1308 2006-07-19 15:46:49Z cs $
+ * $Id: Project.cpp 1352 2006-11-07 08:18:12Z cs $
  */
 
 #include <config.h>
@@ -85,7 +85,7 @@ Project::Project()
 
     start = 0;
     end = 0;
-    now = time(0);
+    setNow(time(0));
 
     minEffort = 0.0;
     resourceLimits = 0;
@@ -249,6 +249,14 @@ Project::getScenarioIndex(const QString& id) const
     return scenarioList.getIndex(id);
 }
 
+void
+Project::setNow(time_t n)
+{
+    /* Align 'now' time to timing resolution. If the resolution is
+     * changed later, this has to be done again. */
+    now = (n / scheduleGranularity) * scheduleGranularity;
+}
+
 void
 Project::setWorkingHours(int day, const QPtrList<Interval>& l)
 {
@@ -486,16 +494,18 @@ Project::getJournalIterator() const
 }
 
 bool
-Project::pass2(bool noDepCheck, bool& fatalError)
+Project::pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings)
 {
+    int oldErrors = errors;
+
     if (taskList.isEmpty())
     {
         TJMH.errorMessage(i18n("The project does not contain any tasks."));
+        errors++;
         return FALSE;
     }
 
     QDict<Task> idHash;
-    bool error = FALSE;
 
     /* The optimum size for the localtime hash is twice the number of time
      * slots times 2 (because of timeslot and timeslot - 1s). */
@@ -517,10 +527,8 @@ Project::pass2(bool noDepCheck, bool& fatalError)
     }
     // Create cross links from dependency lists.
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
-    {
-        if (!(*tli)->xRef(idHash))
-            error = TRUE;
-    }
+        (*tli)->xRef(idHash, errors, warnings);
+
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
     {
         // Set dates according to implicit dependencies
@@ -552,7 +560,7 @@ Project::pass2(bool noDepCheck, bool& fatalError)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if (!(*tli)->preScheduleOk((*sci)->getSequenceNo() - 1))
             {
-                error = TRUE;
+                errors++;
                 fatalError = true;
             }
 
@@ -566,6 +574,7 @@ Project::pass2(bool noDepCheck, bool& fatalError)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if ((*tli)->loopDetector(chkedTaskList))
             {
+                errors++;
                 fatalError = true;
                 return FALSE;
             }
@@ -577,32 +586,31 @@ Project::pass2(bool noDepCheck, bool& fatalError)
             for (TaskListIterator tli(taskList); *tli != 0; ++tli)
                 if (!(*tli)->checkDetermination((*sci)->getSequenceNo() - 1))
                 {
-                    error = TRUE;
+                    errors++;
                     fatalError = true;
                 }
         if (fatalError)
             return false;
     }
 
-    return !error;
+    return errors == oldErrors;
 }
 
 bool
-Project::scheduleScenario(Scenario* sc)
+Project::scheduleScenario(Scenario* sc, int& errors, int& warnings)
 {
-    bool error = FALSE;
+    int oldErrors = errors;
 
     setProgressInfo(i18n("Scheduling scenario %1...").arg(sc->getId()));
 
     int scIdx = sc->getSequenceNo() - 1;
     prepareScenario(scIdx);
 
-    if (!schedule(scIdx))
+    if (!schedule(scIdx, errors, warnings))
     {
         if (DEBUGPS(2))
             qDebug(i18n("Scheduling errors in scenario '%1'.")
                    .arg(sc->getId()));
-        error = TRUE;
         if (breakFlag)
             return false;
     }
@@ -612,12 +620,12 @@ Project::scheduleScenario(Scenario* sc)
     {
         if (!(*rli)->bookingsOk(scIdx))
         {
-            error = TRUE;
+            errors++;
             break;
         }
     }
 
-    return !error;
+    return errors == oldErrors;
 }
 
 void
@@ -635,7 +643,7 @@ Project::completeBuffersAndIndices()
 }
 
 bool
-Project::scheduleAllScenarios()
+Project::scheduleAllScenarios(int& errors, int& warnings)
 {
     bool schedulingOk = TRUE;
     for (ScenarioListIterator sci(scenarioList); *sci; ++sci)
@@ -645,7 +653,7 @@ Project::scheduleAllScenarios()
                 qDebug(i18n("Scheduling scenario '%1' ...")
                        .arg((*sci)->getId()));
 
-            if (!scheduleScenario(*sci))
+            if (!scheduleScenario(*sci, errors, warnings))
                 schedulingOk = FALSE;
             if (breakFlag)
                 return false;
@@ -662,7 +670,7 @@ Project::overlayScenario(int base, int sc)
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
         (*tli)->overlayScenario(base, sc);
 
-    for (ScenarioListIterator sli(scenarioList[base]->getSubListIterator());
+    for (ScenarioListIterator sli(scenarioList[sc]->getSubListIterator());
          *sli; ++sli)
         overlayScenario(sc, (*sli)->getSequenceNo() - 1);
 }
@@ -722,26 +730,36 @@ Project::finishScenario(int sc)
 }
 
 bool
-Project::schedule(int sc)
+Project::schedule(int sc, int& errors, int& warnings)
 {
-    bool error = FALSE;
+    int oldErrors = errors;
 
     // The scheduling function only cares about leaf tasks. Container tasks
     // are scheduled automatically when all their childern are scheduled. So
     // we create a task list that only contains leaf tasks.
-    TaskList sortedTasks;
-    int leafTasks = 0;
+    TaskList allLeafTasks;
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
         if (!(*tli)->hasSubs())
-        {
-            sortedTasks.append(*tli);
-            leafTasks++;
-        }
+            allLeafTasks.append(*tli);
 
-    sortedTasks.setSorting(CoreAttributesList::PrioDown, 0);
-    sortedTasks.setSorting(CoreAttributesList::PathCriticalnessDown, 1);
-    sortedTasks.setSorting(CoreAttributesList::SequenceUp, 2);
-    sortedTasks.sort();
+    allLeafTasks.setSorting(CoreAttributesList::PrioDown, 0);
+    allLeafTasks.setSorting(CoreAttributesList::PathCriticalnessDown, 1);
+    allLeafTasks.setSorting(CoreAttributesList::SequenceUp, 2);
+    allLeafTasks.sort();
+
+    /* The workItems list contains all tasks that are ready to be scheduled at
+     * any given iteration. When a tasks has been scheduled completely, this
+     * list needs to be updated again as some tasks may now have become ready
+     * to be scheduled. */
+    TaskList workItems;
+    int sortedTasks = 0;
+    for (TaskListIterator tli(allLeafTasks); *tli != 0; ++tli)
+    {
+        if ((*tli)->isReadyForScheduling())
+            workItems.append(*tli);
+        if ((*tli)->isSchedulingDone())
+            sortedTasks++;
+    }
 
     bool done;
     /* While the scheduling process progresses, the list contains more and
@@ -750,7 +768,6 @@ Project::schedule(int sc)
      * the list when we start, we initialize the timer with a very large
      * number so the first round of cleanup is done right after the first
      * scheduling pass. */
-    int cleanupTimer = 100000;
     breakFlag = false;
     do
     {
@@ -764,7 +781,7 @@ Project::schedule(int sc)
          * task that can be scheduled. It the determines the time slot that
          * will be scheduled during this run for all subsequent tasks as well.
          */
-        for (TaskListIterator tli(sortedTasks); *tli != 0; ++tli)
+        for (TaskListIterator tli(workItems); *tli != 0; ++tli)
         {
             if (slot == 0)
             {
@@ -791,7 +808,7 @@ Project::schedule(int sc)
                     if (DEBUGPS(5))
                         qDebug("Marking task '%s' as runaway",
                                (*tli)->getId().latin1());
-                    error = TRUE;
+                    errors++;
                     slot = 0;
                     continue;
                 }
@@ -821,27 +838,29 @@ Project::schedule(int sc)
                 break;
 
             // Schedule this task for the current time slot.
-            (*tli)->schedule(sc, slot, scheduleGranularity);
+            if ((*tli)->schedule(sc, slot, scheduleGranularity))
+            {
+                workItems.clear();
+                int oldSortedTasks = sortedTasks;
+                sortedTasks = 0;
+                for (TaskListIterator tli(allLeafTasks); *tli != 0; ++tli)
+                {
+                    if ((*tli)->isReadyForScheduling())
+                        workItems.append(*tli);
+                    if ((*tli)->isSchedulingDone())
+                        sortedTasks++;
+                }
+                // Update the progress bar after every 10th completed tasks.
+                if (oldSortedTasks / 10 != sortedTasks / 10)
+                {
+                    setProgressBar(sortedTasks - allLeafTasks.count(),
+                                   sortedTasks);
+                    setProgressInfo
+                        (i18n("Scheduling scenario %1 at %1")
+                         .arg(getScenarioId(sc)).arg(time2tjp(slot)));
+                }
+            }
         }
-
-        /* Remove all fully scheduled tasks from the list in regular
-         * intervals. This is fairly expensive, so we need to balance the
-         * frequency with the performance improvements due to the shortened
-         * list. We also provide progress feedback via a signal. */
-        if (++cleanupTimer > 4000)
-        {
-            cleanupTimer = 0;
-            TaskList tmpList;
-            for (TaskListIterator tli(sortedTasks); *tli != 0; ++tli)
-                if (!(*tli)->isSchedulingDone())
-                    tmpList.append(*tli);
-            sortedTasks = tmpList;
-            setProgressBar(leafTasks - sortedTasks.count(), leafTasks);
-            setProgressInfo
-                (i18n("Scheduling scenario %1 at %1")
-                 .arg(getScenarioId(sc)).arg(time2tjp(slot)));
-        }
-
     } while (!done && !breakFlag);
 
     if (breakFlag)
@@ -849,10 +868,11 @@ Project::schedule(int sc)
         setProgressInfo("");
         setProgressBar(0, 0);
         TJMH.errorMessage(i18n("Scheduling aborted on user request"));
+        errors++;
         return false;
     }
 
-    if (error)
+    if (errors != oldErrors)
         for (TaskListIterator tli(taskList); *tli != 0; ++tli)
             if ((*tli)->isRunaway())
                 if ((*tli)->getScheduling() == Task::ASAP)
@@ -867,17 +887,16 @@ Project::schedule(int sc)
                               "project time frame. Try using an earlier "
                               "project start date.").arg((*tli)->getId()));
 
-    if (!error)
+    if (errors == oldErrors)
         setProgressBar(100, 100);
 
     /* Check that the resulting schedule meets all the requirements that the
      * user has specified. */
     setProgressInfo(i18n("Checking schedule of scenario %1")
                     .arg(getScenarioId(sc)));
-    if (!checkSchedule(sc))
-        error = TRUE;
+    checkSchedule(sc, errors, warnings);
 
-    return !error;
+    return errors == oldErrors;
 }
 
 void
@@ -887,15 +906,15 @@ Project::breakScheduling()
 }
 
 bool
-Project::checkSchedule(int sc) const
+Project::checkSchedule(int sc, int& errors, int& warnings) const
 {
-    int errors = 0;
+    int oldErrors = errors;
     for (TaskListIterator tli(taskList); *tli != 0; ++tli)
     {
         /* Only check top-level tasks, since they recursively check their sub
          * tasks. */
         if ((*tli)->getParent() == 0)
-            (*tli)->scheduleOk(sc, errors);
+            (*tli)->scheduleOk(sc, errors, warnings);
         if (maxErrors > 0 && errors >= maxErrors)
         {
             TJMH.errorMessage
@@ -905,7 +924,7 @@ Project::checkSchedule(int sc) const
         }
     }
 
-    return errors == 0;
+    return errors == oldErrors;
 }
 
 Report*
@@ -989,10 +1008,12 @@ Project::loadFromXML( const QString& inpFile )
       qDebug("Empty !" );
    }
    bool fatalError;
-   if (!pass2(TRUE, fatalError))
+   int errors = 0;
+   int warnings = 0;
+   if (!pass2(TRUE, fatalError, errors, warnings))
        return FALSE;
-   scheduleAllScenarios();
-   return true;
+   scheduleAllScenarios(errors, warnings);
+   return errors == 0;
 }
 
 
