@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Project.h 1313 2006-07-27 10:50:04Z cs $
+ * $Id: Project.h 1351 2006-10-31 20:34:24Z cs $
  */
 
 #ifndef _Project_h_
@@ -216,7 +216,7 @@ public:
      * Set the date that TaskJuggler uses as current date for all
      * computations. This mainly affects status reporting and the computation
      * of the completion degree of tasks. */
-    void setNow(time_t n) { now = n; }
+    void setNow(time_t n);
     /**
      * Get the date that TaskJuggler uses as current date.
      */
@@ -771,12 +771,12 @@ public:
      * tree has been contructed.
      * @return Only if all tests were successful TRUE is returned.
      */
-    bool pass2(bool noDepCheck, bool& fatalError);
+    bool pass2(bool noDepCheck, bool& fatalError, int& errors, int& warnings);
 
-    bool scheduleScenario(Scenario* sc);
+    bool scheduleScenario(Scenario* sc, int& errors, int& warnings);
     void breakScheduling();
     void completeBuffersAndIndices();
-    bool scheduleAllScenarios();
+    bool scheduleAllScenarios(int& errors, int& warnings);
     void generateReports() const;
 
     bool generateXMLReport() const;
@@ -790,9 +790,9 @@ private:
     void prepareScenario(int sc);
     void finishScenario(int sc);
 
-    bool schedule(int sc);
+    bool schedule(int sc, int& errors, int& warnings);
 
-    bool checkSchedule(int sc) const;
+    bool checkSchedule(int sc, int& errors, int& warnings) const;
 
     /// The start date of the project
     time_t start;
