@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: ReportElement.h 1312 2006-07-22 14:28:45Z cs $
+ * $Id: ReportElement.h 1336 2006-09-26 18:09:50Z cs $
  */
 #ifndef _ReportElement_h_
 #define _ReportElement_h_
@@ -28,6 +28,7 @@
 #include "TableColumnFormat.h"
 #include "TableColumnInfo.h"
 #include "Report.h"
+#include "ReportElementBase.h"
 
 class QStringList;
 
@@ -50,7 +51,7 @@ class CustomAttributeDefinition;
  * @short A class that forms the basic element of a report.
  * @author Chris Schlaeger <cs@kde.org>
  */
-class ReportElement
+class ReportElement : public ReportElementBase
 {
 public:
     enum BarLabelText { BLT_EMPTY = 0, BLT_LOAD };
@@ -95,6 +96,12 @@ public:
     void setEnd(time_t e) { end = e; }
     time_t getEnd() const { return end; }
 
+    void setPeriod(const Interval& iv)
+    {
+        start = iv.getStart();
+        end = iv.getEnd();
+    }
+
     bool isHidden(const CoreAttributes* c, ExpressionTree* et) const;
     bool isRolledUp(const CoreAttributes* c, ExpressionTree* et) const;
 
@@ -144,16 +151,12 @@ public:
 
     int taskRootLevel() const;
 
-    bool setLoadUnit(const QString& u);
-
     void setTimeFormat(const QString& tf) { timeFormat = tf; }
     const QString getTimeFormat() const { return timeFormat; }
 
     void setShortTimeFormat(const QString& tf) { shortTimeFormat = tf; }
     const QString& getShortTimeFormat() const { return shortTimeFormat; }
 
-    const RealFormat& getNumberFormat() const { return numberFormat; }
-
     void setShowPIDs(bool s) { showPIDs = s; }
     bool getShowPIDs() const { return showPIDs; }
 
@@ -181,10 +184,6 @@ public:
     const TableColumnFormat* getColumnFormat(const QString& key) const;
 
     void setMacros(TableLineInfo* tli);
-    QString scaledDuration(double t, const RealFormat& realFormat,
-                           bool showUnit = false, bool longUnit = false) const;
-    QString scaledLoad(double t, const RealFormat& realFormat,
-                       bool showUnit = false, bool longUnit = false) const;
 
     virtual void genHeadDefault(TableCellInfo*) = 0;
     virtual void genHeadCurrency(TableCellInfo*) = 0;
@@ -286,7 +285,6 @@ protected:
                         const QValueList<double>& factors) const;
     void reportValue(double value, const QString& bgcol, bool bold);
 
-    Report* report;
     QValueList<int> scenarios;
     QPtrList<TableColumnInfo> columns;
     QDict<TableColumnFormat> columnFormat;
@@ -300,8 +298,6 @@ protected:
 
     QString timeFormat;
     QString shortTimeFormat;
-    RealFormat numberFormat;
-    RealFormat currencyFormat;
 
     /* We store the location of the report definition in case we need it
      * for error reporting. */
@@ -328,8 +324,6 @@ protected:
      * taskRoot specifies this task. If set it always ends with a '.'. */
     QString taskRoot;
 
-    LoadUnit loadUnit;
-
     bool showPIDs;
 
     bool accumulate;
