@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Resource.cpp 1233 2005-12-01 12:00:24Z cs $
+ * $Id: Resource.cpp 1373 2007-01-25 15:13:13Z cs $
  */
 
 #include "Resource.h"
@@ -45,14 +45,6 @@ static uint* DayEndIndex = 0;
 static uint* WeekEndIndex = 0;
 static uint* MonthEndIndex = 0;
 
-/* To save memory when using large resource lists that are only scarcely used
- * for the project, we only initialize the resource scoreboard when the
- * resource is actually allocated. Since such unused resources can still be
- * used in reports, we use this faked scoreboard. It reflects the global
- * working hours and global vacations. So the reported values for unused
- * resources are not 100% correct. */
-SbBooking** Resource::FakeScoreboard = 0;
-
 Resource::Resource(Project* p, const QString& i, const QString& n,
                    Resource* pr, const QString& df, uint dl)
     : CoreAttributes(p, i, n, pr, df, dl)
@@ -60,9 +52,6 @@ Resource::Resource(Project* p, const QString& i, const QString& n,
     sbSize = (p->getEnd() + 1 - p->getStart()) /
         p->getScheduleGranularity() + 1;
 
-    if (!FakeScoreboard)
-        initFakeScoreboard();
-
     vacations.setAutoDelete(TRUE);
     shifts.setAutoDelete(TRUE);
 
@@ -189,12 +178,6 @@ Resource::~Resource()
 
     delete limits;
 
-    if (FakeScoreboard)
-    {
-        delete [] FakeScoreboard;
-        FakeScoreboard = 0;
-    }
-
     project->deleteResource(this);
 }
 
@@ -332,48 +315,6 @@ Resource::initScoreboard()
     }
 }
 
-void
-Resource::initFakeScoreboard()
-{
-    FakeScoreboard = new SbBooking*[sbSize];
-
-    // First mark all FakeScoreboard slots as unavailable (1).
-    for (uint i = 0; i < sbSize; i++)
-        FakeScoreboard[i] = (SbBooking*) 1;
-
-    // Then change all worktime slots to 0 (available) again.
-    for (time_t day = project->getStart(); day < project->getEnd() + 1;
-         day += project->getScheduleGranularity())
-    {
-        int dow = dayOfWeek(day, FALSE);
-        for (QPtrListIterator<Interval>
-             ivi(project->getWorkingHoursIterator(dow)); *ivi != 0; ++ivi)
-            if ((*ivi)->contains
-                (Interval(secondsOfDay(day),
-                          secondsOfDay(day + project->getScheduleGranularity()
-                                       - 1))))
-            {
-                FakeScoreboard[sbIndex(day)] = (SbBooking*) 0;
-                break;
-            }
-    }
-
-    // Mark all global vacation slots as such (2)
-    for (VacationListIterator ivi(project->getVacationListIterator());
-         *ivi != 0; ++ivi)
-    {
-        if ((*ivi)->getStart() > project->getEnd() ||
-            (*ivi)->getEnd() < project->getStart())
-            continue;
-        uint startIdx = sbIndex((*ivi)->getStart() >= project->getStart() ?
-                                (*ivi)->getStart() : project->getStart());
-        uint endIdx = sbIndex((*ivi)->getEnd() <= project->getEnd() ?
-                              (*ivi)->getEnd() : project->getEnd());
-        for (uint idx = startIdx; idx <= endIdx; ++idx)
-            FakeScoreboard[idx] = (SbBooking*) 2;
-    }
-}
-
 uint
 Resource::sbIndex(time_t date) const
 {
@@ -518,14 +459,14 @@ Resource::book(Booking* nb)
 {
     uint idx = sbIndex(nb->getStart());
 
-    return bookSlot(idx, nb);
+    return bookSlot(idx, nb, 0);
 }
 
 bool
-Resource::bookSlot(uint idx, SbBooking* nb)
+Resource::bookSlot(uint idx, SbBooking* nb, int overtime)
 {
     // Make sure that the time slot is still available.
-    if (scoreboard[idx] != 0)
+    if (scoreboard[idx] > (SbBooking*) overtime)
     {
         delete nb;
         return FALSE;
@@ -553,7 +494,7 @@ Resource::bookSlot(uint idx, SbBooking* nb)
 }
 
 bool
-Resource::bookInterval(Booking* nb, int sc, int sloppy)
+Resource::bookInterval(Booking* nb, int sc, int sloppy, int overtime)
 {
     uint sIdx = sbIndex(nb->getStart());
     uint eIdx = sbIndex(nb->getEnd());
@@ -561,7 +502,7 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy)
     bool conflict = FALSE;
 
     for (uint i = sIdx; i <= eIdx; i++)
-        if (scoreboard[i])
+        if (scoreboard[i] > (SbBooking*) overtime)
         {
             uint j;
             for (j = i + 1 ; j <= eIdx &&
@@ -625,13 +566,14 @@ Resource::bookInterval(Booking* nb, int sc, int sloppy)
         return FALSE;
 
     for (uint i = sIdx; i <= eIdx; i++)
-        bookSlot(i, new SbBooking(*nb));
+        if (scoreboard[i] <= (SbBooking*) overtime)
+            bookSlot(i, new SbBooking(*nb), overtime);
 
     return TRUE;
 }
 
 bool
-Resource::addBooking(int sc, Booking* nb, int sloppy)
+Resource::addBooking(int sc, Booking* nb, int sloppy, int overtime)
 {
     SbBooking** tmp = scoreboard;
 
@@ -639,7 +581,7 @@ Resource::addBooking(int sc, Booking* nb, int sloppy)
         scoreboard = scoreboards[sc];
     else
         initScoreboard();
-    bool retVal = bookInterval(nb, sc, sloppy);
+    bool retVal = bookInterval(nb, sc, sloppy, overtime);
     // Cross register booking with task.
     if (retVal && nb->getTask())
         nb->getTask()->addBookedResource(sc, this);
@@ -888,9 +830,13 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
 {
     long bookings = 0;
 
-    for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
-        bookings += (*rli)->getAllocatedSlots(sc, startIdx, endIdx, acctType,
-                                              task);
+    if (isGroup())
+    {
+        for (ResourceListIterator rli(*sub); *rli != 0; ++rli)
+            bookings += (*rli)->getAllocatedSlots(sc, startIdx, endIdx,
+                                                  acctType, task);
+        return bookings;
+    }
 
     // If the scoreboard has not been initialized there is no load.
     if (!scoreboards[sc])
@@ -899,9 +845,8 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
     if (task && scenarios[sc].firstSlot >= 0 && scenarios[sc].lastSlot >= 0)
     {
         /* If the load is to be calculated for a certain task, we check
-         * whether this task is in the resource allocation list. This is much
-         * faster than iterating over the whole scoreboard without finding
-         * an allocation. */
+         * whether this task is in the resource allocation list. Only then we
+         * calculate the real number of allocated slots. */
         bool isAllocated = FALSE;
         for (TaskListIterator tli(scenarios[sc].allocatedTasks); *tli; ++tli)
             if (task == *tli)
@@ -919,10 +864,10 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
         if (b < (SbBooking*) 4)
             continue;
         if ((task == 0 ||
-            (task != 0 && task == b->getTask()) &&
-             (acctType == AllAccounts ||
-              (b->getTask()->getAccount() &&
-               b->getTask()->getAccount()->getAcctType() == acctType))))
+             (task != 0 && task == b->getTask())) &&
+            (acctType == AllAccounts ||
+             (b->getTask()->getAccount() &&
+              b->getTask()->getAccount()->getAcctType() == acctType)))
             bookings++;
     }
 
@@ -930,19 +875,19 @@ Resource::getAllocatedSlots(int sc, uint startIdx, uint endIdx,
 }
 
 double
-Resource::getAvailableWorkLoad(int sc, const Interval& period) const
+Resource::getAvailableWorkLoad(int sc, const Interval& period)
 {
     return efficiency * getAvailableTimeLoad(sc, period);
 }
 
 double
-Resource::getAvailableTimeLoad(int sc, const Interval& period) const
+Resource::getAvailableTimeLoad(int sc, const Interval& period)
 {
     return project->convertToDailyLoad(getAvailableTime(sc, period));
 }
 
 long
-Resource::getAvailableTime(int sc, const Interval& period) const
+Resource::getAvailableTime(int sc, const Interval& period)
 {
     Interval iv(period);
     if (!iv.overlap(Interval(project->getStart(), project->getEnd())))
@@ -954,7 +899,7 @@ Resource::getAvailableTime(int sc, const Interval& period) const
 }
 
 long
-Resource::getAvailableSlots(int sc, uint startIdx, uint endIdx) const
+Resource::getAvailableSlots(int sc, uint startIdx, uint endIdx)
 {
     long availSlots = 0;
 
@@ -965,20 +910,16 @@ Resource::getAvailableSlots(int sc, uint startIdx, uint endIdx) const
     }
     else
     {
-        /* If the resource hasn't been allocated, we have no scoreboard. Due
-         * to the const nature of this function we cannot generate it anymore.
-         * So we use the FakeScoreboard to get at least a reasonable estimate
-         * for the available time. */
-        if (!scoreboard || !scoreboards[sc])
+        if (!scoreboards[sc])
         {
-            for (uint i = startIdx; i <= endIdx; i++)
-                if (FakeScoreboard[i] == 0)
-                    availSlots++;
+            scoreboard = scoreboards[sc];
+            initScoreboard();
+            scoreboards[sc] = scoreboard;
         }
-        else
-            for (uint i = startIdx; i <= endIdx; i++)
-                if (scoreboards[sc][i] == 0)
-                    availSlots++;
+
+        for (uint i = startIdx; i <= endIdx; i++)
+            if (scoreboards[sc][i] == 0)
+                availSlots++;
     }
 
     return availSlots;
@@ -1165,6 +1106,18 @@ Resource::isOnShift(const Interval& slot) const
     return FALSE;
 }
 
+void
+Resource::setWorkingHours(int day, const QPtrList<Interval>& l)
+{
+    delete workingHours[day];
+
+    // Create a deep copy of the interval list.
+    workingHours[day] = new QPtrList<Interval>;
+    workingHours[day]->setAutoDelete(true);
+    for (QPtrListIterator<Interval> pli(l); pli; ++pli)
+        workingHours[day]->append(new Interval(**pli));
+}
+
 BookingList
 Resource::getJobs(int sc) const
 {
