@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Shift.cpp 1271 2006-03-02 17:03:48Z cs $
+ * $Id: Shift.cpp 1356 2006-11-11 12:25:33Z cs $
  */
 
 #include "Shift.h"
@@ -90,13 +90,14 @@ bool
 Shift::isOnShift(const Interval& iv) const
 {
     int dow = dayOfWeek(iv.getStart(), FALSE);
+    int ivStart = secondsOfDay(iv.getStart());
+    int ivEnd = secondsOfDay(iv.getEnd());
+    Interval dayIv(ivStart, ivEnd);
     for (QPtrListIterator<Interval> ili(*(workingHours[dow])); *ili != 0; ++ili)
-    {
-        if ((*ili)->contains(Interval(secondsOfDay(iv.getStart()),
-                                  secondsOfDay(iv.getEnd()))))
-            return TRUE;
-    }
-    return FALSE;
+        if ((*ili)->contains(dayIv))
+            return true;
+
+    return false;
 }
 
 bool
