@@ -8,7 +8,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Task.h 1268 2006-02-19 13:35:03Z cs $
+ * $Id: Task.h 1370 2007-01-14 15:54:54Z cs $
  */
 
 #ifndef _Task_h_
@@ -125,6 +125,7 @@ public:
     bool addShift(const Interval& i, Shift* s);
 
     void addAllocation(Allocation* a) { allocations.append(a); }
+    void purgeAllocations() { allocations.clear(); }
     QPtrListIterator<Allocation> getAllocationIterator() const
     {
         return QPtrListIterator<Allocation>(allocations);
@@ -160,6 +161,12 @@ public:
     void setEnd(int sc, time_t s) { scenarios[sc].end = s; }
     const time_t getEnd(int sc) const { return scenarios[sc].end; }
 
+    void setSpecifiedPeriod(int sc, const Interval& iv)
+    {
+        scenarios[sc].specifiedStart = iv.getStart();
+        scenarios[sc].specifiedEnd = iv.getEnd();
+    }
+
     time_t getStartBufferEnd(int sc) const
     {
         return scenarios[sc].startBufferEnd;
@@ -315,14 +322,14 @@ public:
 
     bool isContainer() const { return !sub->isEmpty(); }
 
-    bool xRef(QDict<Task>& hash);
+    bool xRef(QDict<Task>& hash, int& errors, int& warnings);
     void implicitXRef();
     void sortAllocations();
     void saveSpecifiedBookedResources();
     QString resolveId(QString relId);
 
     bool preScheduleOk(int sc);
-    bool scheduleOk(int sc, int& errors) const;
+    bool scheduleOk(int sc, int& errors, int& warnings) const;
     /**
      * Checks for loops in task interdependencies starting with the current
      * task.
@@ -335,7 +342,8 @@ public:
     bool checkDetermination(int sc) const;
     void computeBuffers();
     time_t nextSlot(time_t slotDuration) const;
-    void schedule(int sc, time_t& reqStart, time_t duration);
+    bool isReadyForScheduling() const;
+    bool schedule(int sc, time_t& reqStart, time_t duration);
     void propagateStart(int sc, bool safeMode = TRUE);
     void propagateEnd(int sc, bool safeMode = TRUE);
     void propagateInitialValues(int sc);
@@ -347,6 +355,7 @@ public:
     bool isSchedulingDone() const { return schedulingDone; }
 
     void errorMessage(const char*, ...) const;
+    void warningMessage(const char*, ...) const;
 
     QDomElement xmlElement( QDomDocument& doc, bool absId = true );
 
@@ -391,8 +400,7 @@ private:
     double computeBackwardCriticalness(int sc);
     double computeForwardCriticalness(int sc);
 
-    bool analyzePath(int sc, double minSlack, time_t pathStart,
-                     long busyTime);
+    bool analyzePath(int sc, double minSlack, time_t pathStart, long busyTime);
 
     bool countMilestones(int sc, time_t now, int& totalMilestones,
                          int& completedMilestones,
