@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TaskList.h 1259 2006-01-31 12:04:00Z cs $
+ * $Id: TaskList.h 1352 2006-11-07 08:18:12Z cs $
  */
 #ifndef _TaskList_h_
 #define _TaskList_h_
@@ -33,6 +33,10 @@ public:
         // By default we are always using the first scenario for sorting.
         sortScenario = 0;
     }
+    TaskList(const TaskList& tl) : CoreAttributesList(tl)
+    {
+        sortScenario = tl.sortScenario;
+    }
     virtual ~TaskList() { }
 
     Task* getTask(const QString& id) const;
