@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: TaskScenario.cpp 1295 2006-06-16 17:52:08Z cs $
+ * $Id: TaskScenario.cpp 1331 2006-09-20 20:22:18Z cs $
  */
 
 #include "Resource.h"
@@ -36,6 +36,8 @@ TaskScenario::TaskScenario()
     completionDegree = 0.0;
     scheduled = FALSE;
     criticalness = pathCriticalness = 0.0;
+    startCanBeDetermined = false;
+    endCanBeDetermined = false;
 }
 
 void
