@@ -1,13 +1,14 @@
 /*
  * ProjectFile.cpp - TaskJuggler
  *
- * Copyright (c) 2001, 2002, 2003, 2004 by Chris Schlaeger <cs@kde.org>
+ * Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006
+ * Chris Schlaeger <cs@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Token.h 1214 2005-11-17 20:05:36Z cs $
+ * $Id: Token.h 1264 2006-02-16 16:55:38Z cs $
  */
 
 #ifndef _Token_h_
@@ -24,8 +25,8 @@ typedef enum
 {
     INVALID = 0, EndOfStatement, EndOfFile, MacroBody,
     ID, ABSOLUTE_ID, RELATIVE_ID, PERCENT,
-    RBRACE, LBRACE, RBRACKET, LBRACKET, COMMA, COLON, TILDE, 
-    QUESTIONMARK, MINUS, AND, OR,
+    RBRACE, LBRACE, RBRACKET, LBRACKET, COMMA, COLON, TILDE,
+    QUESTIONMARK, PLUS, MINUS, AND, OR,
     GREATER, SMALLER, EQUAL, GREATEROREQUAL, SMALLEROREQUAL,
     DATE, HOUR, INTEGER, REAL, STRING
 } TokenType;
